@@ -67,16 +67,16 @@ class JS(object):
     }
 
     binary_op = {
-        'Add'    : ' + ',
-        'Sub'    : ' - ',
-        'Mult'   : ' * ',
-        'Div'    : ' / ',
-        'Mod'    : ' % ',
-        'LShift' : ' << ',
-        'RShift' : ' >> ',
-        'BitOr'  : ' | ',
-        'BitXor' : ' ^ ',
-        'BitAnd' : ' & ',
+        'Add'    : '+',
+        'Sub'    : '-',
+        'Mult'   : '*',
+        'Div'    : '/',
+        'Mod'    : '%',
+        'LShift' : '<<',
+        'RShift' : '>>',
+        'BitOr'  : '|',
+        'BitXor' : '^',
+        'BitAnd' : '&',
     }
 
     comparison_op = {
@@ -243,12 +243,12 @@ class JS(object):
 
             self._scope = []
         else:
-            _args = [arg.arg for arg in node.args.args if arg.arg != 'self']
+            _args = [arg for arg in node.args.args if arg.arg != 'self']
             defaults = [None]*(len(_args) - len(node.args.defaults)) + node.args.defaults
 
             args = []
             defaults2 = []
-            for arg, default in zip(node.args.args, defaults):
+            for arg, default in zip(_args, defaults):
                 if arg.arg == 'self':
                     continue
                 if not isinstance(arg, ast.arg):
@@ -608,6 +608,8 @@ class JS(object):
                 if name not in self._functions:
                     self._functions[name] = value
                 return name
+            elif str(value) in self.name_map:
+                return self.name_map[str(value)]
             elif isinstance(value, (int, float)):
                 return f'{value}'
             else:
@@ -717,3 +719,13 @@ def transpile_class(cls, superclass=None, newname=None, **context):
     src = '\n'.join(lines)
     src = textwrap.dedent(src)
     return transpile(src, **context)
+
+
+def transpile_function(func, newname=None, **context):
+    src = inspect.getsource(func)
+    src = textwrap.dedent(src)
+    lines = src.split('\n')
+    if newname:
+        lines[0] = re.sub('def ([^(])*', f'def {newname}', lines[0])
+    src = '\n'.join(lines)
+    return transpile(src, **context)
