@@ -10,3 +10,8 @@ if settings.CHANNELS_ENABLE:
     urlpatterns.append(
         path('reactive/', include('ryzom_django_channels_example.views')),
     )
+
+if settings.CRUDLFAP_ENABLE:
+    from crudlfap import shortcuts as crudlfap
+    crudlfap.site.urlpath = 'crudlfap'
+    urlpatterns.append(crudlfap.site.urlpattern)
